@@ -54,8 +54,9 @@ InlineQueryResult = Union[
 class ApiBase:  # pylint: disable=too-few-public-methods
     """This class contains methods that are not methods Telegram Bot Api."""
 
-    def __init__(self, token: str):
+    def __init__(self, token: str, proxies: Optional[dict]):
         self.token = token
+        self.proxies = proxies
 
     @staticmethod
     def _get_tg_api_method_name(py_style_method_name):
@@ -98,6 +99,12 @@ class ApiBase:  # pylint: disable=too-few-public-methods
         anno_wrapper = AnnotationWrapper(annotation)
         return anno_wrapper.sanitized
 
+    def _make_post_request(self, url, **kwargs):
+        if self.proxies:
+            return requests.post(url, proxies=self.proxies, **kwargs)
+        else:
+            return requests.post(url, **kwargs)
+
     def _make_request(self):
         """Make a request to Telegram Bot Api."""
         args = frames.outer2_args()
@@ -110,8 +117,11 @@ class ApiBase:  # pylint: disable=too-few-public-methods
 
         url = self._get_tg_api_method_url(tg_method_name)
 
-        r = requests.post(
-            url, data=payload, headers={'Content-Type': 'application/json'})
+        r = self._make_post_request(url,
+                                    data=payload,
+                                    headers={
+                                        'Content-Type': 'application/json'},
+                                    )
         return handle_response(r.content.decode('utf-8'), result_type)
 
 
@@ -125,8 +135,8 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
         token (str): token
     """
 
-    def __init__(self, token: str):
-        super().__init__(token=token)
+    def __init__(self, token: str, proxies=Optional[dict]):
+        super().__init__(token=token, proxies=proxies)
 
     def set_chat_photo(
             self,
@@ -144,7 +154,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
         del values['photo']
         files = {'photo': photo}
 
-        r = requests.post(url, files=files, data=values)
+        r = self._make_post_request(url,
+                                    files=files,
+                                    data=values,
+                                    )
         return handle_response(
             r.content.decode('utf-8'), AnnotationWrapper('bool'))
 
@@ -182,7 +195,11 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
             # assert isinstance(png_sticker, io.BytesIO):
             files = {'sticker': sticker}
 
-            r = requests.post(url, files=files, data=values)
+            r = self._make_post_request(url,
+                                        files=files,
+                                        data=values,
+                                        )
+
             return handle_response(
                 r.content.decode('utf-8'), AnnotationWrapper('Message'))
 
@@ -209,7 +226,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 del values['png_sticker']
                 files = {'png_sticker': png_sticker}
 
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('bool'))
         else:
@@ -220,13 +240,19 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
             files['tgs_sticker'] = tgs_sticker
 
             if isinstance(png_sticker, str):
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('bool'))
             else:
                 del values['png_sticker']
                 files['png_sticker'] = png_sticker
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('bool'))
 
@@ -247,7 +273,6 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
 
         url = self._get_tg_api_method_url('createNewStickerSet')
 
-
         if png_sticker is not None:
 
             if isinstance(png_sticker, str):
@@ -257,7 +282,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 del values['png_sticker']
                 files = {'png_sticker': png_sticker}
 
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('bool'))
 
@@ -266,7 +294,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
             del values['tgs_sticker']
             files = {'tgs_sticker': tgs_sticker}
 
-            r = requests.post(url, files=files, data=values)
+            r = self._make_post_request(url,
+                                        files=files,
+                                        data=values,
+                                        )
             return handle_response(
                 r.content.decode('utf-8'), AnnotationWrapper('bool'))
 
@@ -285,7 +316,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
         del values['png_sticker']
         files = {'png_sticker': png_sticker}
 
-        r = requests.post(url, files=files, data=values)
+        r = self._make_post_request(url,
+                                    files=files,
+                                    data=values,
+                                    )
         return handle_response(
             r.content.decode('utf-8'), AnnotationWrapper('File'))
 
@@ -308,7 +342,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
             del values['certificate']
             files = {'certificate': certificate}
 
-            r = requests.post(url, files=files, data=values)
+            r = self._make_post_request(url,
+                                        files=files,
+                                        data=values,
+                                        )
             return handle_response(
                 r.content.decode('utf-8'), AnnotationWrapper('bool'))
         else:
@@ -347,7 +384,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 del values['audio']
                 files = {'audio': audio}
 
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('Message'))
 
@@ -355,7 +395,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 del values['thumb']
                 files = {'thumb': thumb}
 
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('Message'))
 
@@ -364,7 +407,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 del values['audio']
                 del values['thumb']
                 files = {'audio': audio, 'thumb': thumb}
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('Message'))
         else:
@@ -377,7 +423,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 del values['audio']
                 files = {'audio': audio}
 
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('Message'))
 
@@ -405,7 +454,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
         else:
             # assert isinstance(photo, io.BytesIO):
             files = {'photo': photo}
-            r = requests.post(url, files=files, data=values)
+            r = self._make_post_request(url,
+                                        files=files,
+                                        data=values,
+                                        )
             return handle_response(
                 r.content.decode('utf-8'), AnnotationWrapper('Message'))
 
@@ -844,7 +896,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 del values['animation']
                 files = {'animation': animation}
 
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('Message'))
 
@@ -852,7 +907,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 del values['thumb']
                 files = {'thumb': thumb}
 
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('Message'))
 
@@ -861,7 +919,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 del values['animation']
                 del values['thumb']
                 files = {'animation': animation, 'thumb': thumb}
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('Message'))
         else:
@@ -874,7 +935,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 del values['animation']
                 files = {'animation': animation}
 
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('Message'))
 
@@ -936,7 +1000,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 del values['document']
                 files = {'document': document}
 
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('Message'))
 
@@ -944,7 +1011,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 del values['thumb']
                 files = {'thumb': thumb}
 
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('Message'))
 
@@ -953,7 +1023,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 del values['document']
                 del values['thumb']
                 files = {'document': document, 'thumb': thumb}
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('Message'))
         else:
@@ -966,7 +1039,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 del values['document']
                 files = {'document': document}
 
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('Message'))
 
@@ -1069,6 +1145,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
             type: Optional[str] = None,
             allows_multiple_answers: Optional[bool] = None,
             correct_option_id: Optional[int] = None,
+            explanation: Optional[str] = None,
+            explanation_parse_mode: Optional[str] = None,
+            open_period: Optional[int] = None,
+            close_date: Optional[int] = None,
             is_closed: Optional[bool] = None,
             disable_notification: Optional[bool] = None,
             reply_to_message_id: Optional[int] = None,
@@ -1134,7 +1214,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 del values['video']
                 files = {'video': video}
 
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('Message'))
 
@@ -1142,7 +1225,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 del values['thumb']
                 files = {'thumb': thumb}
 
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('Message'))
 
@@ -1151,7 +1237,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 del values['video']
                 del values['thumb']
                 files = {'video': video, 'thumb': thumb}
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('Message'))
         else:
@@ -1163,8 +1252,11 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 # assert isinstance(document, io.BytesIO)
                 del values['video']
                 files = {'video': video}
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
 
-                r = requests.post(url, files=files, data=values)
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('Message'))
 
@@ -1196,7 +1288,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 del values['video_note']
                 files = {'video_note': video_note}
 
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('Message'))
 
@@ -1204,7 +1299,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 del values['thumb']
                 files = {'thumb': thumb}
 
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('Message'))
 
@@ -1213,7 +1311,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 del values['video_note']
                 del values['thumb']
                 files = {'video_note': video_note, 'thumb': thumb}
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('Message'))
         else:
@@ -1226,7 +1327,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
                 del values['video_note']
                 files = {'video_note': video_note}
 
-                r = requests.post(url, files=files, data=values)
+                r = self._make_post_request(url,
+                                            files=files,
+                                            data=values,
+                                            )
                 return handle_response(
                     r.content.decode('utf-8'), AnnotationWrapper('Message'))
 
@@ -1260,7 +1364,10 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
             # assert isinstance(photo, io.BytesIO):
             files = {'voice': voice}
 
-            r = requests.post(url, files=files, data=values)
+            r = self._make_post_request(url,
+                                        files=files,
+                                        data=values,
+                                        )
             return handle_response(
                 r.content.decode('utf-8'), AnnotationWrapper('Message'))
 
@@ -1401,6 +1508,7 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
 
     def send_dice(self,
                   chat_id: Union[int, str],
+                  emoji: Optional[str] = None,
                   disable_notification: Optional[bool] = None,
                   reply_to_message_id: Optional[int] = None,
                   reply_markup: Optional[
@@ -1420,7 +1528,8 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
         """Use this method to change the list of the bot's commands. Returns True on success."""
         return self._make_request()
 
-    def set_sticker_set_thumb(self, name: str, user_id: int, thumb: Optional[Union[BinaryIO, str]] = None) -> bool:
+    def set_sticker_set_thumb(self, name: str, user_id: int, thumb: Optional[
+        Union[BinaryIO, str]] = None) -> bool:
         """Use this method to set the thumbnail of a sticker set. Animated thumbnails can be set for animated sticker
         sets only. Returns True on success."""
         if thumb is None:
@@ -1434,9 +1543,9 @@ class Api(ApiBase):  # pylint: disable=too-many-public-methods
             files = {'thumb': thumb}
 
             url = self._get_tg_api_method_url('setStickerSetThumb')
-            r = requests.post(url, files=files, data=values)
+            r = self._make_post_request(url,
+                                        files=files,
+                                        data=values,
+                                        )
             return handle_response(
                 r.content.decode('utf-8'), AnnotationWrapper('bool'))
-
-
-
